@@ -22,11 +22,22 @@ def coerce_value(datatype, value):
     Example:
         >>> coerce_value("int", "5")
         5
+
+    If coercion is not possible, the incoercible portion is left changed.
+
+    Example:
+        >>> coerce_value(['int'], ['1', '2', 'c'])
+        [1, 2, 'c']
     """
     return walk(datatype, value, coerce_step)
 
 
 def coerce_step(_, datatype, value, __):
     if type(datatype) == str and type(value) in coercable_types:
-        return NewValue(coerce_to[datatype](value))
+        try:
+            return NewValue(coerce_to[datatype](value))
+        except (TypeError, ValueError):
+            # Because a errors in constructing these types is expected,
+            # pass silently
+            pass
 
